Enum libmimalloc_sys::mi_heap_t [−][src]
pub enum mi_heap_t {}Expand description
First-class heaps that can be destroyed in one go.
Note: The pointers allocated out of a heap can be be freed using
mi_free – there is no mi_heap_free.
Example
use libmimalloc_sys as mi; unsafe { let h = mi::mi_heap_new(); assert!(!h.is_null()); let p = mi::mi_heap_malloc(h, 50); assert!(!p.is_null()); // use p... mi::mi_free(p); // Clean up the heap. Note that pointers allocated from `h` // are *not* invalided by `mi_heap_delete`. You would have // to use (the very dangerous) `mi_heap_destroy` for that // behavior mi::mi_heap_delete(h); }