Function libmimalloc_sys::mi_aligned_alloc
source · pub unsafe extern "C" fn mi_aligned_alloc(
alignment: usize,
size: usize
) -> *mut c_voidExpand description
Allocate size bytes aligned by alignment with alignment as the first
parameter.
Return pointer to the allocated memory or null if out of memory.