Function libmimalloc_sys::mi_check_owned [−][src]
pub unsafe extern "C" fn mi_check_owned(p: *const c_void) -> bool
Check safely if any pointer is part of the default heap of this thread.
p may be any pointer -- not required to be previously allocated by the
default heap for this thread, or any other mimalloc heap. Returns true
if p points to a block in the default heap, false otherwise.
Note: expensive function, linear in the pages in the heap.