Function libmimalloc_sys::mi_heap_get_default [−][src]
pub unsafe extern "C" fn mi_heap_get_default() -> *mut mi_heap_t
Get the default heap that is used for mi_malloc et al.
pub unsafe extern "C" fn mi_heap_get_default() -> *mut mi_heap_t
Get the default heap that is used for mi_malloc et al.