Function libmimalloc_sys::mi_heap_new
source · pub unsafe extern "C" fn mi_heap_new() -> *mut mi_heap_tExpand description
Create a new heap that can be used for allocation.
pub unsafe extern "C" fn mi_heap_new() -> *mut mi_heap_tCreate a new heap that can be used for allocation.