Function libmimalloc_sys::mi_malloc
source · pub unsafe extern "C" fn mi_malloc(size: usize) -> *mut c_voidExpand description
Allocate size bytes.
Returns pointer to the allocated memory or null if out of memory.
Returns a unique pointer if called with size 0.