Function libmimalloc_sys::mi_posix_memalign[][src]

pub unsafe extern "C" fn mi_posix_memalign(
    ptr: *mut *mut c_void,
    alignment: usize,
    size: usize
) -> c_int

Allocate size of bytes aligned by alignment and place the address of the allocated memory to ptr.

Returns zero on success, invalid argument for invalid alignment, or out-of-memory.