Function libmimalloc_sys::mi_aligned_alloc [−][src]
Allocate size bytes aligned by alignment with alignment as the first
parameter.
Return pointer to the allocated memory or null if out of memory.
Allocate size bytes aligned by alignment with alignment as the first
parameter.
Return pointer to the allocated memory or null if out of memory.