Function libmimalloc_sys::mi_aligned_alloc [−][src]
pub unsafe extern "C" fn mi_aligned_alloc(
alignment: usize,
size: usize
) -> *mut c_void
Allocate size bytes aligned by alignment with alignment as the first
parameter.
Return pointer to the allocated memory or null if out of memory.