[][src]Function libmimalloc_sys::mi_heap_delete

pub unsafe extern "C" fn mi_heap_delete(heap: *mut mi_heap_t)

Delete a previously allocated heap.

This will release resources and migrate any still allocated blocks in this heap (efficienty) to the default heap.

If heap is the default heap, the default heap is set to the backing heap.