Function libmimalloc_sys::mi_malloc_aligned[][src]

pub unsafe extern "C" fn mi_malloc_aligned(
    size: usize,
    alignment: usize
) -> *mut c_void

Allocate size bytes aligned by alignment.

Return pointer to the allocated memory or null if out of memory.

Returns a unique pointer if called with size 0.