pub unsafe extern "C" fn mi_stats_get_json(
buf_size: usize,
buf: *mut c_char,
) -> *mut c_charExpand description
Get the statistics for the current subprocess aggregated over all its heaps as JSON.
Returns pointer to the buffer or NULL on failure. Use mi_free() to free the buffer if the buf parameter was NULL.