pub unsafe extern "C" fn mi_unsafe_heap_page_is_under_utilized(
heap: *mut mi_heap_t,
p: *mut c_void,
perc_threshold: usize,
) -> boolExpand description
Check if the heap page containing p is under-utilized.
Safety
Assumes the page belonging to p is only accessed by the calling thread.